@@ -1,12 +1,12 @@
 ;;; vimish-fold.el --- Fold text like in Vim -*- lexical-binding: t; -*-
 ;;
-;; Copyright © 2015–2016 Mark Karpov <markkarpov@openmailbox.org>
+;; Copyright © 2015–2017 Mark Karpov <markkarpov92@gmail.com>
 ;; Copyright © 2012–2013 Magnar Sveen <magnars@gmail.com>
 ;;
-;; Author: Mark Karpov <markkarpov@openmailbox.org>
+;; Author: Mark Karpov <markkarpov92@gmail.com>
 ;; Author: Magnar Sveen <magnars@gmail.com>
 ;; URL: https://github.com/mrkkrp/vimish-fold
-;; Version: 0.2.2
+;; Version: 0.2.3
 ;; Package-Requires: ((emacs "24.4") (cl-lib "0.5") (f "0.18.0"))
 ;; Keywords: convenience
 ;;
@@ -27,19 +27,20 @@
 
 ;;; Commentary:
 
-;; This is a package to perform text folding like in Vim. It has the
+;; This is a package to perform text folding like in Vim.  It has the
 ;; following features:
 ;;
 ;; * folding of active regions;
 ;;
 ;; * good visual feedback: it's obvious which part of text is folded;
 ;;
-;; * persistence by default: when you close file your folds don't disappear;
+;; * persistence by default: when you kill a buffer your folds don't
+;;   disappear;
 ;;
 ;; * persistence scales well, you can work on hundreds of files with lots of
 ;;   folds without adverse effects;
 ;;
-;; * it doesn't break indentation or something;
+;; * it does not break indentation;
 ;;
 ;; * folds can be toggled from folded state to unfolded and back very
 ;;   easily;
@@ -120,6 +121,16 @@ This can be a number or NIL.  If it's NIL value returned of
   :type 'boolean
   :package-version '(vimish-fold . "0.2.1"))
 
+(defcustom vimish-fold-persist-on-saving t
+  "Whether to save folds on buffer saving.
+
+Other than on saving, folds are also saved on buffer killing and
+when user quits Emacs.  Turn this option off if the additional
+overhead is undesirable."
+  :tag "Save folds on buffer saving."
+  :type 'boolean
+  :package-version '(vimish-fold . "0.2.3"))
+
 (defvar vimish-fold-folded-keymap (make-sparse-keymap)
   "Keymap which is active when point is placed on folded text.")
 
@@ -155,7 +166,7 @@ If ON is NIL, make the text editable again."
   (let ((inhibit-read-only t))
     (with-silent-modifications
       (funcall
-       (if on #'set-text-properties #'remove-text-properties)
+       (if on #'add-text-properties #'remove-text-properties)
        beg end (list 'read-only on)))))
 
 (defun vimish-fold--get-header (beg end)
@@ -460,7 +471,7 @@ BUFFER-OR-NAME defaults to current buffer."
                 (let ((version-control 'never))
                   (condition-case nil
                       (progn
-                        (f-mkdir vimish-fold-dir)
+                        (apply #'f-mkdir (f-split vimish-fold-dir))
                         (write-region (point-min) (point-max) fold-file)
                         (message nil))
                     (file-error
@@ -510,7 +521,9 @@ For globalized version of this mode see `vimish-gold-global-mode'."
   (let ((fnc (if vimish-fold-mode #'add-hook #'remove-hook)))
     (funcall fnc 'find-file-hook   #'vimish-fold--restore-folds)
     (funcall fnc 'kill-buffer-hook #'vimish-fold--save-folds)
-    (funcall fnc 'kill-emacs-hook  #'vimish-fold--kill-emacs-hook)))
+    (funcall fnc 'kill-emacs-hook  #'vimish-fold--kill-emacs-hook)
+    (when vimish-fold-persist-on-saving
+      (funcall fnc 'before-save-hook #'vimish-fold--save-folds))))
 
 ;;;###autoload
 (define-globalized-minor-mode vimish-fold-global-mode
